## Used to specify a RML Page Template on the filesystem to be used within
## the portal_skins in the ZMI.

from RMLPageTemplate import RMLPageTemplate
from AccessControl import ClassSecurityInfo
from Products.CMFCore.DirectoryView import registerFileExtension, registerMetaType
from Products.CMFCore.FSPageTemplate import FSPageTemplate
from Products.CMFCore.FSMetadata import FSMetadata
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.utils import expandpath
from Products.PageTemplates.ZopePageTemplate import Src
import Globals

class FSRMLPageTemplate(FSPageTemplate, RMLPageTemplate):
    """
    Wrapper for RML Page Template
    """
    content_type = 'text/xml'

    meta_type = "Filesystem RML Page Template"

    security = ClassSecurityInfo()
    security.declareObjectProtected(View)

    manage_options = (FSPageTemplate.manage_options[:2] + \
                      ({'label': 'View RML',
                        'action': 'view_rml'},) +
                      FSPageTemplate.manage_options[2:])

    def __init__(self, id, filepath, fullname = None, properties = None):
        """
        """
        FSPageTemplate.__init__(self, id, filepath, fullname, properties)

    def __call__(self, *args, **kwargs):
        """
        """
        return RMLPageTemplate.__call__(self, *args, **kwargs)

    def _readFile(self, reparse):
        FSPageTemplate._readFile(self, reparse)
        if reparse:
            e_filepath = expandpath(self._filepath)
            metadata = FSMetadata(e_filepath)
            metadata.read()
            props = metadata.getProperties()
            if props:
                self.__dict__.update(metadata.getProperties())

_s = Src()
setattr(FSRMLPageTemplate, 'source.xml', _s)
setattr(FSRMLPageTemplate, 'source.html', _s)
del _s

Globals.InitializeClass(FSRMLPageTemplate)

registerFileExtension('rml', FSRMLPageTemplate)
registerMetaType('RML Page Template', FSRMLPageTemplate)
